polimorfo.annotations package
=============================

Submodules
----------

polimorfo.annotations.bounbingbox module
----------------------------------------

.. automodule:: polimorfo.annotations.bounbingbox
    :members:
    :undoc-members:
    :show-inheritance:

polimorfo.annotations.converters module
---------------------------------------

.. automodule:: polimorfo.annotations.converters
    :members:
    :undoc-members:
    :show-inheritance:

polimorfo.annotations.mask module
---------------------------------

.. automodule:: polimorfo.annotations.mask
    :members:
    :undoc-members:
    :show-inheritance:

polimorfo.annotations.polygon module
------------------------------------

.. automodule:: polimorfo.annotations.polygon
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: polimorfo.annotations
    :members:
    :undoc-members:
    :show-inheritance:
